<?php
namespace Block;

/**
 * Blog Slider - Main Class
 * 
 * Slideshow/carousel for Blog using Slick Slider from https://github.com/kenwheeler/slick
 * Note - only partial configuration options are implemented for the tutorial
 * at https://www.schlix.com/documentation/v2/application-development/block/advanced-block-example.html
 * 
 * @copyright 2020 SCHLIX Web Inc
 *
 * @license MIT
 *
 * @package blogslider
 * @version 1.0
 * @author  SCHLIX Web Inc 
 * @link    https://www.schlix.com
 */

/**
 * BlogSlider is inherited from https://www.schlix.com/api/2.x/namespace/namespace_s_c_h_l_i_x/class_s_c_h_l_i_x_1_1cms_block.html
 */
class BlogSlider extends \SCHLIX\cmsBlock {

    /**
     * Run the block
     * @global \App\Users $CurrentUser
     * @global \SCHLIX\cmsHTMLPageHeader $HTMLHeader
     */
    public function Run() {
        global $CurrentUser, $HTMLHeader;
        
        // Get values from config
        $config_max_entries = $this->config['int_max_entries'];        
        $config_max_summary_length = $this->config['int_max_summary_length'];        
        $config_category_id = (int) $this->config['int_only_category'];
        // Instantiate a new blog class
        $blog = new \App\Blog();
        // For more info: https://www.schlix.com/api/2.x/namespace/namespace_app/class_app_1_1_blog.html
        // which is inherited from https://www.schlix.com/api/2.x/namespace/namespace_s_c_h_l_i_x/class_s_c_h_l_i_x_1_1cms_application___many_to_many.html
        // which is inherited from https://www.schlix.com/api/2.x/namespace/namespace_s_c_h_l_i_x/class_s_c_h_l_i_x_1_1cms_application___hierarchical_tree___list.html
        // which is inherited from https://www.schlix.com/api/2.x/namespace/namespace_s_c_h_l_i_x/class_s_c_h_l_i_x_1_1cms_application___categorized_list.html
        // which is inherited from https://www.schlix.com/api/2.x/namespace/namespace_s_c_h_l_i_x/class_s_c_h_l_i_x_1_1cms_application___list.html
        // which is inherited from https://www.schlix.com/api/2.x/namespace/namespace_s_c_h_l_i_x/class_s_c_h_l_i_x_1_1cms_application___basic.html
        // there you go!
        $config_max_entries = ($config_max_entries == 0) ? 15 : $config_max_entries;
        
        // initialize variables
        $items = null;
        // Was category specified by the user? If so, then just get the blog
        // articles for the specific category
        if ($config_category_id > 0)
        {
            $items = $blog->getItemsByCategoryID($config_category_id, '*', ' status = 1 ', 0, $config_max_entries, 'date_created', 'DESC', true);
        } else
        // otherwise, display slideshow for the latest blog articles
        {
            $items = $blog->getAllItems('*', ' status = 1 ', 0, $config_max_entries, 'date_created', 'DESC', true);
        }
        $total_item_count = ___c($items);
        if ($total_item_count == 0)
        {
            echo '<!-- No blog article found -->';
            return; // don't do any additional processing
        }
        // these are the config values from https://github.com/kenwheeler/slick
        // We're going to be very verbose so you can easily read it
        // Note: we only implement partial option since this is just for a tutorial demo
        // for https://www.schlix.com/documentation/v2/application-development/block/advanced-block-example.html
        $config_adaptive_height = is_value_true($this->config['bool_infinite']);
        $config_acessibility = is_value_true($this->config['bool_accessibility']);
        $config_adaptive_height = is_value_true($this->config['bool_adaptive_height']);
        $config_arrows = is_value_true($this->config['bool_arrows']);
        $config_bool_arrows_inside = is_value_true($this->config['bool_arrows_inside']); 
        $config_autoplay =  is_value_true($this->config['bool_autoplay']);
        $config_infinite = is_value_true($this->config['bool_infinite']);
        $config_slides_to_show = max (min($this->config['int_slides_to_show'], 10), 1);
        $config_slides_to_scroll = max (min($this->config['int_slides_to_scroll'], 10), 1);
        $config_autoplay_speed_milli_seconds = 1000 * (max (min($this->config['int_autoplay_speed_second'], 20), 1));
        $config_dots = is_value_true($this->config['bool_dots']);
        $config_dots_class = is_value_true($this->config['str_dots_class']);
        $config_fade = is_value_true((int) $this->config['int_fade']);        
        $config_center_mode = is_value_true($this->config['bool_center_mode']);
        // shows you how to set the default to TRUE if the value hasn't been set (e.g. first install)
        $config_draggable = array_key_exists ('bool_draggable', $this->config ) ? is_value_true($this->config['bool_draggable']) : true;
        
        // now put it in a variable where it will be encoded as JSON so the options
        // can be passed before blogslider.js is loaded
        $slick_slider_options = [
            'accessibility' => $config_acessibility, 
            'adaptiveHeight' => $config_adaptive_height,
            'arrows' => $config_arrows,
            'dots' => $config_dots,
            'draggable' => $config_draggable,
            'fade' => $config_fade,
            'autoplay' => $config_autoplay,
            'autoplaySpeed' => $config_autoplay_speed_milli_seconds,
            'centerMode' => $config_center_mode,
            'infinite' => $config_infinite,
            'slidesToShow' => $config_slides_to_show,
            'slidesToScroll' => $config_slides_to_scroll
            
                ];
        if (!empty($config_dots_class))
            $slick_slider_options['dotsClass'] = $config_dots_class;
        // ---------------- end of config settings -------------------------//
        $arr_css_class = ['blogslider'];
        if ($config_bool_arrows_inside)
            $arr_css_class[] = 'blogslider-arrow-insider'; // for full width images, otherwise arrow won't show up
        $css_class_blog_slider = implode(' ', $arr_css_class);
        // You can actually add these 4 lines to the view.block.template.php instead if you prefer
        $this->CSS('slick/slick.css');
        $this->CSS('slick/slick-theme.css');
        $this->CSS('blogslider.css');
        $this->JAVASCRIPT('slick/slick.min.js');        
        // you can also use $HTMLHeader instead
        // For more info: https://www.schlix.com/api/2.x/namespace/namespace_s_c_h_l_i_x/class_s_c_h_l_i_x_1_1cms_h_t_m_l_page_header.html
        // We'll have to use a unique block name like blogslider_{$this->block_name}
        // because there can be more than 1 slideshow on a single page
        // since a block can be called more than once (for different instance)
        // and hence we reference it by the CSS ID instead of CSS class
        $HTMLHeader->JAVASCRIPT_TEXT(
                "var slick_slider_options_{$this->block_name} = ".json_encode($slick_slider_options).";".
                "$(document).ready(function(){
  $('#blogslider_{$this->block_name}').slick(slick_slider_options_{$this->block_name});
});");
        // Now slick_slider_options has been specified, load view.block.template.php
        $this->loadTemplateFile('view.block', compact(array_keys(get_defined_vars())));
    }

}
