<?php
/**
 * Blog Slider - Config
 * 
 * Slideshow/carousel for Blog using Slick Slider from https://github.com/kenwheeler/slick
 *
 * Slideshow/carousel for Blog using Slick Slider from https://github.com/kenwheeler/slick
 *
 * @copyright 2020 SCHLIX Web Inc
 *
 * @license MIT
 *
 * @package blogslider
 * @version 1.0
 * @author  SCHLIX Web Inc 
 * @link    https://www.schlix.com
 */
if (!defined('SCHLIX_VERSION'))
    die('No Access');

    
/**
 * This function is to create a category tree for the dropdown box int_only_category
 * If you'd like, you can add your function. 
 * @param array $category_array
 * @param int $parent
 * @param int $depth
 * @return string
 */
function generateTree($category_array, $parent = 0, $depth = 0) {
    if ($depth > 100)
        return ''; // Make sure not to have an endless recursion
    $ul_css_class = 'nested-category-list';
    if ($depth > 0)
        $ul_css_class =  '';

    $subtree = array();
    $menu_count = ___c($category_array);
    for ($i = 0; $i < $menu_count; $i++) {
        if ($category_array[$i]['parent_id'] == $parent) {
            $childnodes = generateTree($category_array, $category_array[$i]['cid'], $depth + 1);
            $title = str_repeat('--', $depth).$category_array[$i]['title'];
            $subtree[]= array('cid' => $category_array[$i]['cid'], 'title' =>$title); 

            if (!empty($childnodes))
                $subtree = array_merge($subtree, $childnodes);
        }
    } 
    return $subtree;
}

// main code
$tmp_blog = new \App\blog();
$allcategories = $tmp_blog->getAllCategories("*",'status > 0',0,0,'title','ASC');    

$html_category_choice = generateTree($allcategories)
?>
<schlix-config:integerbox config-key="int_max_entries" min="0" max="100" label="<?= ___('Maximum number of slideshow to be displayed (descending order)') ?>"   config-default-value="10" />
<schlix-config:integerbox config-key="int_max_summary_length" min="0" max="10000" label="<?= ___('Maximum length of summary text to be displayed') ?>"   config-default-value="100" />
<schlix-config:dropdownlist   config-key="int_only_category" label="<?=  ___('Only display the following category') ?>">
    <schlix-config:option value=""><?= ___('(None)') ?> </schlix-config:option>
    <?php foreach ($html_category_choice as $choice): ?>
        <schlix-config:option value="<?= $choice['cid'] ?>"><?= ___h($choice['title']) ?> </schlix-config:option>
    <?php endforeach ?>
</schlix-config:dropdownlist>
<schlix-config:integerbox config-key="int_cache_result_seconds" label="<?= ___("Cache result for (in seconds)") ?>"   config-default-value="120" />
<p class="small"><?= ___('Caching the result set will help with the performance of your website') ?></p>

<hr />
<!-- Options specific to slick slider -->
<h3><?= ___('Slick Slider options') ?></h3>

<x-ui:row>
    <!-- column -->
    <x-ui:column md="6">
        <!-- config -->
        <schlix-config:checkbox config-key="bool_accessibility" label="<?= ___('Enables tabbing and arrow key navigation') ?>" />
        <schlix-config:checkbox config-key="bool_adaptive_height" label="<?= ___('Adapts slider height to the current slide') ?>" />
        <schlix-config:checkbox config-key="bool_arrows" label="<?= ___('Enable Next/Prev arrows') ?>" />
        <schlix-config:checkbox config-key="bool_arrows_inside" label="<?= ___('Display arrows on the inside (for full width slideshow)') ?>" />
        <schlix-config:checkbox config-key="bool_draggable" label="<?= ___('Enables desktop dragging') ?>" />
        
        <schlix-config:checkbox config-key="bool_infinite" label="<?= ___('Infinite slides') ?>" />
        <schlix-config:checkbox config-key="bool_center_mode" label="<?= ___('Enables centered view with partial prev/next slides. Use with odd numbered slides to show counts.') ?>" />
        <schlix-config:integerbox config-key="int_slides_to_show" min="1" max="10" label="<?= ___('Number of slides to show') ?>"   config-default-value="1" />
        <schlix-config:integerbox config-key="int_slides_to_scroll" min="1" max="10" label="<?= ___('Number of slides to scroll') ?>"   config-default-value="1" />
        <!-- end config -->
    </x-ui:column>
    <!-- column -->
    <x-ui:column md="6">
        <!-- config -->
<schlix-config:radiogroup config-key="int_fade" label="<?= ___('Animation') ?>">
    <schlix-config:option value="0"><?= ___S('Slide') ?></schlix-config:option>
    <schlix-config:option value="1"><?= ___S('Fade') ?></schlix-config:option>
</schlix-config:radiogroup>
<fieldset>
    <legend><?= ___('Dots Indicator') ?></legend>
    <schlix-config:checkbox config-key="bool_dots" label="<?= ___('Show current slide indicator dots') ?>" />
    <schlix-config:textbox config-key="str_dots_class" label="<?= ___('Custom Dots CSS class') ?>" config-default-value="slick-dots" />
</fieldset>
<fieldset>
    <legend><?= ___('Autoplay') ?></legend>
    <schlix-config:checkbox config-key="bool_autoplay" label="<?= ___('Enables auto play of slides') ?>" />
    <schlix-config:integerbox config-key="int_autoplay_speed_second" min="1" max="20" label="<?= ___('Auto play change interval (second)') ?>"   config-default-value="3" />
</fieldset>
        
        <!-- end config -->
    </x-ui:column>    
</x-ui:row>
<!-- end options -->
<?php /*
?>
<p><?= ___('Example Configuration') ?></p>
<!-- Example begins -->
<schlix-config:textbox config-key='str_example_1' label="<?= ___('Textbox Example') ?>' class='form-control' />
<schlix-config:textarea config-key='str_example_2' label="<?= ___('Textarea Example') ?>" class='wysiwyg' />             
<schlix-config:textarea config-key='str_example_3' label="<?= ___('Non-WYSIWYG textarea example') ?>" class='form-control'  />             

<schlix-config:integerbox config-key='int_integerbox_example' config-default-value="1" min="1" max="200"  label="<?= ___('Integer box example with default value') ?>' class='form-control' />

<schlix-config:checkbox config-key='bool_checkbox_example' label="<?= ___('Checkbox Example') ?>' />

<schlix-config:dropdownlist class="form-control" config-key="str_option_select" label="<?= ___('Dropdown list example') ?>" >
    <schlix-config:option value="0"><?= ___('Please select') ?></schlix-config:option>
    <schlix-config:option value="<?= ___h('opt1') ?>"><?= ___h('Option 1') ?></schlix-config:option>
    <schlix-config:option value="<?= ___h('opt2') ?>"><?= ___h('Option 2') ?></schlix-config:option>
    <schlix-config:option value="<?= ___h('opt3') ?>"><?= ___h('Option 3') ?></schlix-config:option>
</schlix-config:dropdownlist> 

<schlix-config:radiogroup config-key="int_option_radio" label="<?= ('Radio group example') ?>">
    <schlix-config:option value="1"><?= ___h('Option 1') ?></schlix-config:option>
    <schlix-config:option value="2"><?= ___h('Option 2') ?></schlix-config:option>
    <schlix-config:option value="3"><?= ___h('Option 3') ?></schlix-config:option>
</schlix-config:radiogroup>

<schlix-config:checkboxgroup config-key="int_option_checkbox" label="<?= ('Checkbox group example') ?>">
    <schlix-config:option value="1"><?= ___h('Option 1') ?></schlix-config:option>
    <schlix-config:option value="2"><?= ___h('Option 2') ?></schlix-config:option>
    <schlix-config:option value="3"><?= ___h('Option 3') ?></schlix-config:option>
</schlix-config:checkboxgroup>    
<!-- Example Ends -->
*/ ?>