<?php
/**
 * Blog Slider - Main page view template. Lists both categories and items with parent_id = 0 and category_id = 0 
 * 
 * Slideshow/carousel for Blog using Slick Slider from https://github.com/kenwheeler/slick
 * 
 * @copyright 2020 SCHLIX Web Inc
 *
 * @license MIT
 *
 * @package blogslider
 * @version 1.0
 * @author  SCHLIX Web Inc 
 * @link    https://www.schlix.com
 */
if (!defined('SCHLIX_VERSION')) die('No Access');

// NOTE - always add id = $this->block_name, which is unique, so frontend developer
// can style it
?>

<div class="<?= $css_class_blog_slider ?>" id="blogslider_<?= $this->block_name ?>">
    <?php for ($i = 0; ($i < $config_max_entries) && ($i < $total_item_count); $i++): ?>
    <?php 
        // the follow fields from gk_blog_item will be used:
        // title, summary, summary_intro_image, summary_secondary_headline (if available),
        // the code below will be executed in a loop
        $item = $items[$i];
        $link = $blog->createFriendlyURL("action=viewitem&id={$item['id']}");
        $thumb_filename = $blog->getBlogImage('image_large', $item['summary_intro_image']); 
        
        // We'd like to add a paragraph
        $secondary_headline = $item['summary_secondary_headline'] ? $item['summary_secondary_headline'] : mb_substr(strip_tags($item['summary']), 0, 255,'UTF-8') . '...';
        if ($item['summary_secondary_headline']) {
            $secondary_headline = $item['summary_secondary_headline'];
        } else {
            $article_summary = strip_tags($item['summary']);
            $article_summary_space_position = mb_strpos($article_summary, ' ', $config_max_summary_length-5);
            if ($article_summary_space_position == 0 || $article_summary_space_position > $config_max_summary_length)
                $article_summary_space_position = $config_max_summary_length;
            $secondary_headline = mb_substr($article_summary, 0, $article_summary_space_position,'UTF-8');
        }
        // begin looped slideshow
        // if you want to check read permission before displaying it
        if ($CurrentUser->hasReadPermission($item['permission_read'])):
    ?>
        <div class="blogslider-image" style="background-image:url(<?= $thumb_filename ?>)">
            <div class="container d-flex h-100">
                <div class="row align-self-center w-100">
                    <div class="col-8 mx-auto">
                        <div class="text-center blogslider-text">
                            <h1><a href="<?= $link ?>"><?= ___h($item['title']) ?></a></h1>
                            <p>
                            <?= $secondary_headline ?>                                 
                            </p>
                        </div>
                    </div>
                </div>                
            </div>
            
        </div>
    <?php endif; ?>
    <?php endfor; ?>
</div>